DEFAULT_SERVER_HOST = "localhost"
DEFAULT_SERVER_PORT = 11211
DEFAULT_POOL_MINSIZE = 2
DEFAULT_POOL_MAXSIZE = 5
DEFAULT_TIMEOUT = 1
DEFAULT_MAX_KEY_LENGTH = 250
DEFAULT_MAX_VALUE_LENGTH = 1024 * 1024  # 1 megabyte

STORED = b"STORED\r\n"
NOT_STORED = b"NOT_STORED\r\n"
EXISTS = b"EXISTS\r\n"
NOT_FOUND = b"NOT_FOUND\r\n"
DELETED = b"DELETED\r\n"
TOUCHED = b"TOUCHED\r\n"

END = b"END\r\n"
VERSION = b"VERSION"
OK = b"OK\r\n"



__all__ = [
    "ClientException",
    "ValidationException",
    "ResponseException",
    "ConnectException",
    "TimeoutException",
]


class ClientException(Exception):
    """Base Exception for AioMemCached"""

    pass


class ValidationException(ClientException):
    pass


class ResponseException(ClientException):
    def __init__(self, raw_cmd, response, ext_message=None):
        message = "Memcached::[{}] response is not expected:{}{}".format(
            raw_cmd, "{}, ".format(ext_message) if ext_message else "", response
        )
        super().__init__(message)


class ConnectException(ClientException, ConnectionError):
    pass


class TimeoutException(ConnectException, TimeoutError):
    pass



"""memcached client, based on mixpanel's memcache_client library

Usage example::

    import asyncio
    import aiomemcached


    async def example():
        c = aiomemcached.Client()
        await c.set(b"some_key", b"Some value")
        value = await c.get(b"some_key")
        print(value)
        values = await c.multi_get(b"some_key", b"other_key")
        print(values)
        await c.delete(b"another_key")


    asyncio.run(example())
"""

from .client import Client
from .exceptions import (
    ClientException,
    ConnectException,
    ResponseException,
    TimeoutException,
    ValidationException,
)

__all__ = (
    "Client",
    "ClientException",
    "ValidationException",
    "ResponseException",
    "ConnectException",
    "TimeoutException",
)

__name__ = "AioMemcached"
__version__ = "0.8.4"

__author__ = "Nikolay Kim"
__author_email__ = "fafhrd91@gmail.com"
__maintainer__ = "Rex Zhang <rex.zhang@gmail.com>"

__licence__ = "BSD"

__description__ = "A pure-Python(3.7+) asyncio memcached client, fork from aiomcache. "
__project_url__ = "https://github.com/rexzhang/aiomemcached"
